ApiException class abstract

Base exception class for all API-related errors

Implemented types
Implementers

Constructors

ApiException(String message, [dynamic details])
Creates an API exception with a message and optional details
const

Properties

details → dynamic
Optional additional details about the error
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited