RateLimitException class

Exception thrown when rate limit is exceeded

Inheritance

Constructors

RateLimitException([String message = 'Rate limit exceeded', dynamic details])
Creates a rate limit exception
const

Properties

details → dynamic
Optional additional details about the error
finalinherited
hashCode int
The hash code for this object.
no setterinherited
message String
The error message
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited