LoggingInterceptor class

Interceptor for logging HTTP requests and responses

Implemented types

Constructors

LoggingInterceptor({Logger? logger})
Creates a logging interceptor with optional custom logger

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onRequest(Uri url, HttpMethod method, Map<String, String> headers, dynamic body) Future<void>
Called before a request is sent
override
onResponse(Response response) Future<void>
Called after a response is received
override
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited