dequeue method
Removes and returns the next request from the queue
Implementation
QueuedRequest? dequeue() {
if (_queue.isEmpty) return null;
return _queue.removeFirst();
}
Removes and returns the next request from the queue
QueuedRequest? dequeue() {
if (_queue.isEmpty) return null;
return _queue.removeFirst();
}