ServerException class
Exception thrown when the server returns an error response
- Inheritance
-
- Object
- ApiException
- ServerException
Constructors
- ServerException(int statusCode, [String message = 'Server error occurred', dynamic details])
-
Creates a server exception with status code
const
Properties
- details → dynamic
-
Optional additional details about the error
finalinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- message → String
-
The error message
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- statusCode → int
-
The HTTP status code returned by the server
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited