NetworkChecker class
Utility class to check network connectivity
Constructors
- NetworkChecker()
- Creates a network checker
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
-
onConnectivityChanged
→ Stream<
ConnectivityResult> -
Listens to connectivity changes
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
dispose(
) → void - Disposes the network checker
-
getConnectivityStatus(
) → Future< ConnectivityResult> - Gets the current connectivity status
-
isConnected(
) → Future< bool> - Checks if device is currently connected to the internet
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
waitForConnection(
{Duration? timeout}) → Future< void> - Waits until internet connection is available
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited