OfflineQueue class

Queue for storing offline requests

Constructors

OfflineQueue({int maxSize = 100})
Creates an offline queue

Properties

hashCode int
The hash code for this object.
no setterinherited
isEmpty bool
Returns true if the queue is empty
no setter
isFull bool
Returns true if the queue is full
no setter
length int
Returns the number of queued requests
no setter
maxSize int
Maximum number of requests to store in the queue
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clears all queued requests
dequeue() QueuedRequest?
Removes and returns the next request from the queue
enqueue(String method, String url, {Map<String, String>? headers, dynamic body}) String
Adds a request to the queue
getAll() List<QueuedRequest>
Gets all queued requests
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
peek() QueuedRequest?
Peeks at the next request without removing it
remove(String id) bool
Removes a specific request by ID
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited