QueuedRequest class
Represents a queued request
Constructors
Properties
- body → dynamic
-
Request body
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
headers
→ Map<
String, String> ? -
Request headers
final
- id → String
-
Unique identifier for the request
final
- method → String
-
HTTP method
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- timestamp → DateTime
-
When the request was queued
final
- url → String
-
Request URL
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited